==> lxqt-l10n_0.11.2.orig.tar.xz: lxqt-l10n-0.11.2/lxqt-policykit/lxqt-policykit-agent/lxqt-policykit-agent_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>LXQtPolicykit::PolicykitAgent</name>
    <message>
        <location filename="../../src/policykitagent.cpp" line="71"/>
        <location filename="../../src/policykitagent.cpp" line="158"/>
        <source>PolicyKit Information</source>
        <translation>Information PolicyKit</translation>
    </message>
    <message>
        <location filename="../../src/policykitagent.cpp" line="71"/>
        <source>Another authentization in progress. Please try it again later.</source>
        <translation>Une autre authentification est en cours. Essayez un peu plus tard SVP.</translation>
    </message>
    <message>
        <location filename="../../src/policykitagent.cpp" line="139"/>
        <source>Authorization Failed</source>
        <translation>Echec de l&apos;autorisation</translation>
    </message>
    <message>
        <location filename="../../src/policykitagent.cpp" line="139"/>
        <source>Authorization failed for some reason</source>
        <translation>Echec de l&apos;autorisation pour une raison donnée</translation>
    </message>
    <message>
        <location filename="../../src/policykitagent.cpp" line="153"/>
        <source>PolicyKit Error</source>
        <translation>Erreur PolicyKit</translation>
    </message>
</context>
<context>
    <name>PolicykitAgentGUI</name>
    <message>
        <location filename="../../src/policykitagentgui.ui" line="14"/>
        <source>Authentication Required</source>
        <translation>Authentification est nécessaire</translation>
    </message>
    <message>
        <location filename="../../src/policykitagentgui.ui" line="55"/>
        <source>Identity:</source>
        <translation>Identité :</translation>
    </message>
    <message>
        <location filename="../../src/policykitagentgui.ui" line="65"/>
        <source>Password:</source>
        <translation>Mot de passe :</translation>
    </message>
</context>
</TS>

==> lxqt-l10n-0.13.0_p20181121.tar.xz: lxqt-l10n-0.13.0_p20181121/lxqt-policykit/lxqt-policykit-agent/lxqt-policykit-agent_fr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>LXQtPolicykit::PolicykitAgent</name>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="71"/>
        <location filename="../../../src/policykitagent.cpp" line="158"/>
        <source>PolicyKit Information</source>
        <translation>Information PolicyKit</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="71"/>
        <source>Another authentization in progress. Please try it again later.</source>
        <translation>Une autre authentification est en cours. Essayez un peu plus tard SVP.</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="139"/>
        <source>Authorization Failed</source>
        <translation>Echec de l&apos;autorisation</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="139"/>
        <source>Authorization failed for some reason</source>
        <translation>Echec de l&apos;autorisation pour une raison donnée</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagent.cpp" line="153"/>
        <source>PolicyKit Error</source>
        <translation>Erreur PolicyKit</translation>
    </message>
</context>
<context>
    <name>PolicykitAgentGUI</name>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="14"/>
        <source>Authentication Required</source>
        <translation>Authentification est nécessaire</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="55"/>
        <source>Identity:</source>
        <translation>Identité :</translation>
    </message>
    <message>
        <location filename="../../../src/policykitagentgui.ui" line="65"/>
        <source>Password:</source>
        <translation>Mot de passe :</translation>
    </message>
</context>
</TS>
